summaryrefslogtreecommitdiff
path: root/src/scm/webid-oidc/cache.scm
diff options
context:
space:
mode:
Diffstat (limited to 'src/scm/webid-oidc/cache.scm')
-rw-r--r--src/scm/webid-oidc/cache.scm4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/scm/webid-oidc/cache.scm b/src/scm/webid-oidc/cache.scm
index 8b8c480..dbf0112 100644
--- a/src/scm/webid-oidc/cache.scm
+++ b/src/scm/webid-oidc/cache.scm
@@ -1,4 +1,4 @@
;; webid-oidc, implementation of the Solid specification
;; Copyright (C) 2020, 2021 Vivien Kraus
;; This program is free software: you can redistribute it and/or modify
@@ -52,7 +52,7 @@
(let ((xdg-cache-home
(or (getenv "XDG_CACHE_HOME")
(format #f "~a/.cache" (getenv "HOME")))))
- (format #f "~a/webid-oidc" xdg-cache-home)))
+ (format #f "~a/disfluid" xdg-cache-home)))
(define (web-cache-dir dir)
(when (thunk? dir)
@@ -1,4 +1,4 @@
-;; webid-oidc, implementation of the Solid specification
+;; disfluid, implementation of the Solid specification
;; Copyright (C) 2020, 2021 Vivien Kraus
;; This program is free software: you can redistribute it and/or modify